#ifndef MY_FILTER
#define MY_FILTER


#include "i3d/image3d.h"


/**
 * The function performs 1D convolution along the x-axis of the input
 * image \e in with the \e filter. The result is stored in the output
 * image \e out. Borders are treated by extending the input with zeros.
 *
 * The function processes correctly only 2D images.
 *
 * This is i3d::GRAY8 to float version.
 */
void Filter_Xaxis(i3d::Image3d<i3d::GRAY8> const &in,
						i3d::Image3d<float> &out,
						const float filter[3]);

/**
 * The function performs 1D convolution along the x-axis of the input
 * image \e in with the \e filter. The result is stored in the output
 * image \e out. Borders are treated by extending the input with zeros.
 *
 * The function processes correctly only 2D images.
 *
 * This is float to float version.
 */
void Filter_Xaxis(i3d::Image3d<float> const &in,
						i3d::Image3d<float> &out,
						const float filter[3]);

/**
 * The function performs 1D convolution along the y-axis of the input
 * image \e in with the \e filter. The result is stored in the output
 * image \e out. Borders are treated by extending the input with zeros.
 *
 * The function processes correctly only 2D images.
 */
void Filter_Yaxis(i3d::Image3d<i3d::GRAY8> const &in,
						i3d::Image3d<float> &out,
						const float filter[3]);

/**
 * The function performs 1D convolution along the y-axis of the input
 * image \e in with the \e filter. The result is stored in the output
 * image \e out. Borders are treated by extending the input with zeros.
 *
 * The function processes correctly only 2D images.
 *
 * This version deals with memory in a less efficient way.
 */
void Filter_Yaxis_slower(i3d::Image3d<i3d::GRAY8> const &in,
						i3d::Image3d<float> &out,
						const float filter[3]);

/**
 * The function conducts the UnsharpMask filter.
 */
void UnsharpMask(i3d::Image3d<i3d::GRAY8> const &in,
					  i3d::Image3d<i3d::GRAY8> &out);


/**
 * The function conducts the UnsharpMask filter.
 */
void UnsharpMask2(i3d::Image3d<i3d::GRAY8> const &in,
					   i3d::Image3d<i3d::GRAY8> &out);

#endif
